@@ -7,9 +7,12 @@ from json import dumps as json_dumps
 from datetime import datetime, timedelta, timezone
 import pytz
 import ast
+import logging
 
 from .exceptions import *
 
+logger = logging.getLogger(__name__)
+
 class DiaryBase:
     """docstring for Diary."""
 
@@ -17,6 +20,9 @@ class DiaryBase:
     userfeed_url = "https://dnevnik.ru/userfeed"
 
     def __init__(self):
+
+        self._initial_user_info = None
+
         self.session = Session()
         # "Referer" is needed
         self.session.headers = {"User-Agent": UserAgent().random,
@@ -72,12 +78,20 @@ class DiaryBase:
             raw_initial_info = raw_initial_info.split("window.__TALK__STUB__INITIAL__STATE__ = ")[0]
             raw_initial_info = raw_initial_info.split("window.__TALK__INITIAL__STATE__ = ")[0]
             raw_initial_info = raw_initial_info.strip()[:-1]
-            json = json_loads(raw_initial_info)
-            info = json["userSchedule"]["currentChild"]
+            self._initial_user_info = json_loads(raw_initial_info)
+            info = self._initial_user_info["userSchedule"]["currentChild"]
+            
+            logger.debug("User info: " + str(info))
+            logger.debug("Current date according to dnevnik: " + self._initial_user_info["userSchedule"]["currentDate"])
+
             return info["schoolId"], info["groupId"], info["personId"]
 
         raise DataParseError("Cannot find user info in userfeed page")
 
+    @property
+    def initial_user_info(self):
+        return self._initial_user_info
+
 
 class Diary(DiaryBase):
     """docstring for Diary."""
@@ -93,7 +107,7 @@ class Diary(DiaryBase):
         # calculate time if user passes in negative span
         # by default dnevnikru supports only positive and zero span
         if span < 0:
-            date = date - timedelta(days = span)
+            date = date - timedelta(days = abs(span))
             span = abs(span)
 
         # convert date to timestamp
@@ -101,6 +115,7 @@ class Diary(DiaryBase):
             timestamp_date = int(datetime(year = date.year, month = date.month, day = date.day).replace(tzinfo = pytz.utc).timestamp())
         else:
             timestamp_date = int(datetime(year = date.year, month = date.month, day = date.day).timestamp())
+        logger.debug(f"Getting diary for date {timestamp_date} with span {span}")
 
         r = self._get(f"https://dnevnik.ru/api/userfeed/persons/"
                       f"{self.person_id}/schools/"
